.left margin
.if not HLP
.hl 1 Display Commands
.endif hlp
.if HLP
.i-1;3 DISPLAY
.endif hlp
.br
The display commands control how numbers are displayed.  Examples
of these are the page number, chapter number and so on.  Numbers
may be displayed as normal (decimal) numbers, letters, or Roman numerals.
extra text may be added to the numbers via pre or post-fixes.
.bb
The pre and pos-fix may be used to automatically control the format
of various headers.  For example you may automatically underline them,
or print them in boldface on printers that support bolding.
These are illustrated by various examples.
.i5;DSR doesn't support the "pre-fix" or "post-fix" parameters.
.eb
.if hlp
.if RSX
.nj.i5;ADDITIONAL HELP AVAILABLE:
.dhy.ts+10, +10, +10, +10, +10, +10
format	NUMBER	example	CHAPTER
APPENDIX	ELEMENTS	SUBPAGE	LEVELS	
TITLE	SUBTITLE
.j.ehy
.endif RSX
.i-1;4 NUMBER
.endif hlp
.left margin+5
.s.i-5;_.DISPLAY NUMBER ["pre-fix",] [format] [,"post-fix"]
.I-5;_.DNM ["pre-fix",] [format] [,"post-fix"]
.s.x DISPLAY >NUMBER 
controls the format of the page numbers as they are printed at the top of the
page, in the index and in the table of contents. The pre and post-fixes
specify text to be printed before and after the page number.  The pre-fix
may consist of up to 10 characters.
This extra text is only printed on the individual pages, and do not
appear in the index or table of contents page numbers.
.bb
Any flag characters included in the pre or post-fix text are interpreted at
the time the page is printed.  The autoindex and equation flags are ignored
in the pre-fix and tabs are converted to spaces.  If you need to extend the
pre-fix size you can conveniently do this via a substitution.
The number of levels of substitution is reduced, since the pre/post fix
is essentially a level of substitution.
.eb
The pre or post-fixs may be enclosed in either apostrophes (') or quotes
("). See the rules applicable to literal parameters.
The format applies to the page number.  It can be either regular decimal
numbers, Roman numerals, or a sequence of letters. See the table of formats.
If the format is not specified then it remains unchanged.
If you wish to specify the post-fix only, then you must either specify
the pre-fix, the format, or include commas to mark their absence.
.s;The default is:###_.DISPLAY NUMBER "Page " , D , ""
.if hlp.i-6;4 example
.endif hlp
.p
Assume you want pages to be numbered in lower case roman numerals.  You
would use the following command:
.i5;_.DISPLAY NUMBER  RL
.p
As another example say you wish to print a 4 page memorandum and
on each page you want the page number and the total number of pages
as n/4 underlined.  To do this you issue the following command.
.i5;_.DISPLAY NUMBER "_^_&" "/4_\_&"
.br; The first page is numbered ^&1/1\& the second ^&1/2\& and so on.
.p;The RUNOFF manual was produced with the following format:
.i5;_.DISPLAY NUMBER "- " " -".
.IF HLP
.i-6;4 format
.br
.endif hlp
.s2.nf.ts 20,30 .text
            Table of Formats
.s
        ^&Format        Description\& 
.s 
        D	Decimal numbers
		(1,2,3,....)
        LU      Letters uppercase
		(A,B,C,....,Z,AA,AB,AC....)
        LL      Letters lowercase
		(a,b,c,....,z,aa,ab,ac....)
        LM      Letters mixed (first is uppercase) 
		(A,B,C,....,Z,Aa,Ab,...)
        RU      Roman numerals uppercase 
		(I,II,III,IV,....)
        RL      Roman lowercase 
		(i,ii,iii,iv,....)
        RM      Roman mixed 
		(I,Ii,Iii,Iv,....)
.etx.F 
.if HLP
.i-6;4 CHAPTER
.endif hlp
.s.i-5;_.DISPLAY CHAPTER ["pre-fix",] [format] [,"post-fix"]
.i-5;_.DCH ["pre-fix",] [format] [,"post-fix"]
.S.x DISPLAY >CHAPTER 
controls the format of the chapter numbers as they are printed
when the _.CHAPTER command is used.
The pre and post-fix may be up to 10 characters. They determine what is printed
before and after the chapter number on the title page of each chapter.
See _.DISPLAY NUMBER.
.p;The default is:
.i5;_.DISPLAY CHAPTER "CHAPTER " , D , ""
.p
For example rather than chapters you want sections
with numbering by Roman numerals,
so you include the following in your _.RNO file:
.i5;_.DISPLAY 'Section (' , RU , ')'
.br;When you issue the _.CHAPTER command for the 6'th time you get the
following in the chapter header: 
.i5;Section (VI)
.if hlp;.i-6;4 APPENDIX
.endif hlp
.S.I-5;_.DISPLAY APPENDIX ["pre-fix",] [format] [,"post-fix"]
.i-5;_.DAX ["pre-fix",] [format] [,"post-fix"]
.s.x DISPLAY >APPENDIX 
controls the format of the appendix number.
This works the same way as _.DISPLAY CHAPTER but it applies to output produced
by the _.APPENDIX command.
.p
The default is:
.i5;_.DISPLAY APPENDIX "APPENDIX " , LU , ""
.if HLP
.i-6;4 SUBPAGE
.endif hlp
.s.i-5;_.DISPLAY SUBPAGE [format] 
.i-5;_.DSP [format] 
.s.x DISPLAY >SUBPAGE 
controls the format of the subpage number.  It is normally uppercase letters. 
See _.DISPLAY NUMBER.
.if hlp
.i-6;4 LEVELS
.endif hlp
.bb
.s.tt 6
.i-5;_.DISPLAY LEVELS [fm1,][fm2,][fm3,][fm4,][fm5,][fm6,]
.i-5;_.DISPLAY LEVELS [level,]["pre-fix",] [form,] ["post-fix"]
.I-5;_.DHL [fm1,][fm2,][fm3,][fm4,][fm5,][fm6,]
.eb
.S.x DISPLAY >LEVELS 
sets the header level numbers to be displayed in the selected format. 
fm1 to fm6 are format codes for LEVELS 1 to 6. See _.DISPLAY NUMBER.
.bb
Each format code may be preceeded by a pre-fix and followed by a post-fix.
The pre-fix and post-fix are 10 char literals to appear before and after the
numbers.  If the number is not printed the post-fix is omitted. When the pre
and post-fix are defined the _.HEADER LEVEL command will automatically turn
off underlining and all printer special features before the pre-fix and after
the label. The levels may be specified by number or sequentially.
For example the following will set levels 2 and 3.  In 2 the number is 
underlined and in 3 the title is underlined, but not the number.  Uppercase
letters are used by 2 and roman numerals for 3.
.i5;_.DISPLAY LEVELS 2,"_^_&",LU,"_\_&",RU,"_^_&"
.eb
.i5;(DSR doesn't support Level numbers, pre-fix or post-fix)
.p; The default is:
.i5;_.DISPLAY LEVELS D,D,D,D,D,D
.if hlp
.i-6;4 ELEMENTS
.endif hlp
.S.TEST TEXT 6.I-5;_.DISPLAY ELEMENTS ["l"] [,format] [,"r"] 
.I-5;_.DLE ["l",] [format] [,"r"] 
.S.x DISPLAY >ELEMENTS
This command sets the format of the current LIST element.  The "l" and "r" are
the left and right characters to put around the list number.  See  _.LIST,
_.LIST ELEMENT, _.END LIST for explanations of the list elements. See
_.DISPLAY NUMBER for a table of possible formats. Once you have specified the
display characteristics for a given list it will remain specified even after
more _.LIST or _.END LIST commands. The optional characters may be delimited
by either quotes ["] or a pair of apostrophes ['].  The default format is: 
.i5;_.DISPLAY ELEMENTS "" , D , "."
.br; If you wish to setup your lists at the beginning of the document to
normal outline form you issue the following commands.
.i5;_.LIST 0 _.LIST 0 _.DISPLAY ELEMENTS LU
.i5;_.LIST 0 _.DISPLAY ELEMENTS LL
.I5;_.END LIST 0 _.END LIST 0 _.END LIST 0
.br;This will display lists in Decimal, Capital letters, lowercase letters.
.if hlp
.i-6;4 TITLE
.endif hlp
.bb
.s.tt6.i-5;_.DISPLAY TITLE ["pre-fix"] [,"post-fix"]
.x DISPLAY>TITLE
This command sets up pre and post-fixes to appear with the title at the
top of the page.  The _.DISPLAY TITLE command must appear before the _.TITLE
command or _.CHAPTER command that it modifies.
.eb
.if hlp
.i-6;4 SUBTITLE
.endif hlp
.bb
.s.tt6.i-5;_.DISPLAY SUBTITLE ["pre-fix"] [,"post-fix"]
.x DISPLAY>SUBTITLE
This command sets up pre and post-fixes to appear with the subtitle at the top
of the page.  The _.DISPLAY SUBTITLE command must appear before the _.SUBTITLE
command or _.HEADER LEVEL command that it modifies. 
.eb
.lm
.if HLP
.i-1;3 SAVE
.else HLP
.BB
.hl 1 SAVE/RESTORE Commands
.endif hlp
.br
These commands save the current status for later.  The status is restored
automatically or by a RESTORE command. 
.I5;(NOT AVAILABLE IN DSR)
.if hlp
.IF RSX;.BR;FURTHER HELP: list APPENDIX CHAPTER HEADERS LEVEL STATUS
.ENDIF RSX
.i-1;4 list
.endif hlp
.s.c;^&List of commands saved as part of the status:\&
.nj.s.TAB PROPORTIONAL 4
_.AUTOBREAK	_.AUTOHYPHENATE	_.AUTOPARAGRAPH	_.LOWERCASE	
_.FILL	_.JUSTIFY	_.PERIOD	_.UPPERCASE
.br;_.ENABLE/DISABLE
.lm+5
.TAB PROPORTIONAL 4
.f
BAR	ESCAPE	EQUATION	HYPHENATION	INDEXING	
OVERSTRIKING	SUBSTITUTION	TABS	UNDERLINING
.j
.p;The options specified in the _.PERIOD and _.AUTOHYPHENATE commands are not
saved or restored.
.if hlp.i-6;4 APPENDIX
.endif HLP
.s.tt5.i-5;_.SAVE APPENDIX
.s.x SAVE>APPENDIX
This saves the status to be restored by an _.APPENDIX command.
.if hlp.i-6;4 CHAPTER
.endif hlp
.s.tt5.i-5;_.SAVE CHAPTER
.s.x SAVE>CHAPTER
This saves the status to be restored by a _.CHAPTER command.
.if hlp.i-6;4 HEADERS
.endif hlp
.s.tt5.i-5;_.SAVE HEADERS
.s.x SAVE>HEADERS
This saves the current status which is restored whenever a page header or
page number are printed.  Normally the page header is produced using
the status at the last _.TITLE, _.SUBTITLE or any command which automatically
generates titles and subtitles.
This is useful in preventing or allowing
features as underlining to appear in the page header.
.if hlp.i-6;4 LEVELS
.endif hlp
.s.tt5.i-5;_.SAVE LEVELS
.s.x SAVE>LEVELS
This saves the status to be restored by a _.HEADER LEVEL command.
The status is only restored if the header level number is printed.
Non numbered levels do not restore status.
For example you can restore _.FILL, _.JUSTIFY etc for each sections of
the document.
.if hlp.i-6;4 STATUS
.endif hlp
.s.tt5.i-5;_.SAVE STATUS
.s.x SAVE>STATUS
This saves the status to be restored by the _.RESTORE STATUS command.
.s.tt5.i-5;_.RESTORE STATUS
.s.x RESTORE STATUS
This command restores the status saved by the last SAVE STATUS command.
.EB
